@@ -32,7 +32,6 @@
 #include "utils/memutils.h"
 #include "utils/rel.h"
 #include "utils/syscache.h"
-#include "utils/resowner.h"
 #if PG_VERSION_NUM >= 90200
 #include "catalog/pg_class.h"
 #endif
@@ -410,10 +409,6 @@ static void pg_hint_plan_plpgsql_stmt_beg(PLpgSQL_execstate *estate,
 										  PLpgSQL_stmt *stmt);
 static void pg_hint_plan_plpgsql_stmt_end(PLpgSQL_execstate *estate,
 										  PLpgSQL_stmt *stmt);
-static void plpgsql_query_erase_callback(ResourceReleasePhase phase,
-										 bool isCommit,
-										 bool isTopLevel,
-										 void *arg);
 
 /* GUC variables */
 static bool	pg_hint_plan_enable_hint = true;
@@ -495,9 +490,7 @@ static const HintParser parsers[] = {
  * PL/pgSQL plugin for retrieving string representation of each query during
  * function execution.
  */
-static const char *plpgsql_query_string = NULL;
-static enum PLpgSQL_stmt_types plpgsql_query_string_src;
-
+const char *plpgsql_query_string = NULL;
 PLpgSQL_plugin  plugin_funcs = {
 	NULL,
 	NULL,
@@ -578,8 +571,6 @@ _PG_init(void)
 	/* setup PL/pgSQL plugin hook */
 	var_ptr = (PLpgSQL_plugin **) find_rendezvous_variable("PLpgSQL_plugin");
 	*var_ptr = &plugin_funcs;
-
-	RegisterResourceReleaseCallback(plpgsql_query_erase_callback, NULL);
 }
 
 /*
@@ -3691,10 +3682,7 @@ pg_hint_plan_plpgsql_stmt_beg(PLpgSQL_execstate *estate, PLpgSQL_stmt *stmt)
 	}
 
 	if (expr)
-	{
 		plpgsql_query_string = expr->query;
-		plpgsql_query_string_src = (enum PLpgSQL_stmt_types) stmt->cmd_type;
-	}
 }
 
 /*
@@ -3705,22 +3693,10 @@ pg_hint_plan_plpgsql_stmt_beg(PLpgSQL_execstate *estate, PLpgSQL_stmt *stmt)
 static void
 pg_hint_plan_plpgsql_stmt_end(PLpgSQL_execstate *estate, PLpgSQL_stmt *stmt)
 {
-	if (plpgsql_query_string &&
-		plpgsql_query_string_src == stmt->cmd_type)
+	if ((enum PLpgSQL_stmt_types) stmt->cmd_type == PLPGSQL_STMT_EXECSQL)
 		plpgsql_query_string = NULL;
 }
 
-void plpgsql_query_erase_callback(ResourceReleasePhase phase,
-								  bool isCommit,
-								  bool isTopLevel,
-								  void *arg)
-{
-	if (phase != RESOURCE_RELEASE_AFTER_LOCKS)
-		return;
-	/* Force erase stored plpgsql query string */
-	plpgsql_query_string = NULL;
-}
-
 #define standard_join_search pg_hint_plan_standard_join_search
 #define join_search_one_level pg_hint_plan_join_search_one_level
 #define make_join_rel make_join_rel_wrapper
